var NAVTREEINDEX0 =
{
"1_88_84__epars_8h.html":[17,0,0,5,0],
"1_88_84__epars_8h_source.html":[17,0,0,5,0],
"1_88_84__intloops_8h.html":[17,0,0,5,1],
"1_88_84__intloops_8h_source.html":[17,0,0,5,1],
"2Dfold_8h.html":[17,0,0,9],
"2Dfold_8h_source.html":[17,0,0,9],
"2Dpfold_8h.html":[17,0,0,10],
"2Dpfold_8h.html#a13430ac6a7f90df426774f131647d2c7":[17,0,0,10,9],
"2Dpfold_8h.html#a1aca740e2a75ab2b2951538266e53d64":[17,0,0,10,5],
"2Dpfold_8h.html#a692243dac482a1e158a8e1b7881cfda2":[17,0,0,10,7],
"2Dpfold_8h.html#ae251288f50dd4ae7d315af0085775f71":[17,0,0,10,8],
"2Dpfold_8h.html#afe994291458ee2ac34d3eb825ef62a15":[17,0,0,10,6],
"2Dpfold_8h_source.html":[17,0,0,10],
"BoyerMoore_8h.html":[17,0,0,7,0],
"BoyerMoore_8h_source.html":[17,0,0,7,0],
"LPfold_8h.html":[17,0,0,53],
"LPfold_8h.html#ae85bf55053e9fb295208be322e0fa07a":[17,0,0,53,5],
"LPfold_8h_source.html":[17,0,0,53],
"Lfold_8h.html":[17,0,0,51],
"Lfold_8h_source.html":[17,0,0,51],
"MEA_8h.html":[17,0,0,54],
"MEA_8h_source.html":[17,0,0,54],
"PKplex_8h_source.html":[17,0,0,70],
"PS__dot_8h.html":[17,0,0,78],
"PS__dot_8h_source.html":[17,0,0,78],
"ProfileAln_8h_source.html":[17,0,0,76],
"RNApuzzler_8h.html":[17,0,0,6,0,0],
"RNApuzzler_8h_source.html":[17,0,0,6,0,0],
"RNAstruct_8h.html":[17,0,0,81],
"RNAstruct_8h_source.html":[17,0,0,81],
"RNAturtle_8h.html":[17,0,0,6,0,1],
"RNAturtle_8h_source.html":[17,0,0,6,0,1],
"SHAPE_8h.html":[17,0,0,0,3],
"SHAPE_8h.html#a71b84eb0dd69e5c256f4ecf8f78cf314":[17,0,0,0,3,3],
"SHAPE_8h_source.html":[17,0,0,0,3],
"ali__plex_8h_source.html":[17,0,0,11],
"alifold_8h.html":[17,0,0,12],
"alifold_8h.html#a1c48869c03b49a342bf4cbdd61900081":[17,0,0,12,3],
"alifold_8h.html#a502948a122a2af5b914355b1f3ea2f61":[17,0,0,12,13],
"alifold_8h.html#ac484c6bd429bafbd353b91044508d8e9":[17,0,0,12,11],
"alifold_8h.html#af3cbac6ff5d706d6e414677841ddf94c":[17,0,0,12,12],
"alifold_8h_source.html":[17,0,0,12],
"all_8h.html":[17,0,0,4,0],
"all_8h_source.html":[17,0,0,4,0],
"aln__util_8h.html":[17,0,0,13],
"aln__util_8h_source.html":[17,0,0,13],
"alphabet_8h.html":[17,0,0,14],
"alphabet_8h_source.html":[17,0,0,14],
"annotated.html":[16,0],
"api_features.html":[7],
"boltzmann__sampling_8h.html":[17,0,0,15],
"boltzmann__sampling_8h_source.html":[17,0,0,15],
"bug.html":[13],
"callbacks.html":[7,1],
"callbacks.html#callback_descriptions":[7,1,1],
"callbacks.html#callbacks_intro":[7,1,0],
"centroid_8h.html":[17,0,0,16],
"centroid_8h.html#a7dcc64bcefcf682396dd3bbea02416fe":[17,0,0,16,3],
"centroid_8h.html#ac92486ce514677256f4a832dc518759c":[17,0,0,16,4],
"centroid_8h_source.html":[17,0,0,16],
"char__stream_8h.html":[17,0,0,17],
"char__stream_8h_source.html":[17,0,0,17],
"citelist.html":[14],
"classes.html":[16,1],
"classified_dp.html":[4,11],
"classified_dp.html#classified_dp_api":[4,11,3],
"classified_dp.html#classified_dp_intro":[4,11,0],
"classified_dp.html#density_of_states":[4,11,2],
"classified_dp.html#distance_classes":[4,11,1],
"cofold_8h.html":[17,0,0,18],
"cofold_8h_source.html":[17,0,0,18],
"combinatorics_8h.html":[17,0,0,19],
"combinatorics_8h_source.html":[17,0,0,19],
"commands_8h.html":[17,0,0,20],
"commands_8h_source.html":[17,0,0,20],
"concentrations_8h.html":[17,0,0,21],
"concentrations_8h.html#a163159722a422ba90335a601fc34b8fb":[17,0,0,21,4],
"concentrations_8h_source.html":[17,0,0,21],
"concepts.html":[4],
"consensus_structures.html":[4,10],
"consensus_structures.html#consensus_structure_api":[4,10,1],
"consensus_structures.html#consensus_structure_intro":[4,10,0],
"constants_8h.html":[17,0,0,5,3],
"constants_8h.html#a12c2040f25d8e3a7b9e1c2024c618cb6":[17,0,0,5,3,2],
"constants_8h.html#a307c72605e3713972b4f4fb2d53ea20e":[17,0,0,5,3,1],
"constants_8h.html#a5064c29ab2d1e20c2304b3c67562774d":[17,0,0,5,3,3],
"constants_8h.html#a5e75221c779d618eab81e096f37e32ce":[17,0,0,5,3,5],
"constants_8h.html#a96a9822fa134450197dd454b1478a193":[17,0,0,5,3,4],
"constants_8h.html#ab1e4a8d82f24ed5db01dde5f25269cf1":[17,0,0,5,3,0],
"constants_8h.html#ad1bd6eabac419670ddd3c9ed82145988":[17,0,0,5,3,7],
"constants_8h.html#ae646250fd59311356c7e5722a81c3a96":[17,0,0,5,3,6],
"constants_8h_source.html":[17,0,0,5,3],
"constraints_2basic_8h.html":[17,0,0,0,0],
"constraints_2basic_8h_source.html":[17,0,0,0,0],
"constraints_8h.html":[17,0,0,22],
"constraints_8h_source.html":[17,0,0,22],
"constraints__SHAPE_8h.html":[17,0,0,25],
"constraints__SHAPE_8h_source.html":[17,0,0,25],
"constraints__hard_8h.html":[17,0,0,23],
"constraints__hard_8h_source.html":[17,0,0,23],
"constraints__ligand_8h.html":[17,0,0,24],
"constraints__ligand_8h_source.html":[17,0,0,24],
"constraints__soft_8h.html":[17,0,0,26],
"constraints__soft_8h_source.html":[17,0,0,26],
"convert_8h.html":[17,0,0,5,4],
"convert_8h_source.html":[17,0,0,5,4],
"convert__epars_8h.html":[17,0,0,27],
"convert__epars_8h_source.html":[17,0,0,27],
"cpu_8h_source.html":[17,0,0,8,2],
"data__structures_8h.html":[17,0,0,28],
"data__structures_8h_source.html":[17,0,0,28],
"data_structures.html":[6],
"datastructures_2basic_8h.html":[17,0,0,1,0],
"datastructures_2basic_8h_source.html":[17,0,0,1,0],
"datastructures_2char__stream_8h.html":[17,0,0,1,1],
"datastructures_2char__stream_8h_source.html":[17,0,0,1,1],
"datastructures_2stream__output_8h.html":[17,0,0,1,5],
"datastructures_2stream__output_8h_source.html":[17,0,0,1,5],
"default_8h_source.html":[17,0,0,5,5],
"deprecated.html":[12],
"design.html":[4,12],
"design.html#design_api":[4,12,1],
"design.html#design_intro":[4,12,0],
"dir_1ca6f3a46323f79e1934000abf5d4efb.html":[17,0,0,6],
"dir_1ddf03e95848b6488d60454f7a385ded.html":[17,0,0,8],
"dir_3d74ce004720553e7871f65d12e07ff9.html":[17,0,0,3],
"dir_45ac42044d8b814ecf694abd17d2de12.html":[17,0,0,2],
"dir_511ee2b14d6879b7ada858ff02a7ab24.html":[17,0,0,6,0],
"dir_54da8e06181df970e10d68c1aa7bbb33.html":[17,0,0,4],
"dir_8a4ca9b4a73205797ab566a10a6011af.html":[17,0,0,1],
"dir_8b3d6293463b6781f7bf8859fc72e182.html":[17,0,0,5],
"dir_94a42affd43e91f8a4e9ff1a4c7599c5.html":[17,0,0],
"dir_e78bc76dd94a8744fef38d57611bd23c.html":[17,0,0,0],
"dir_ece6de16e10c3ab1bafd819fa99af76e.html":[17,0,0,7],
"dist__vars_8h.html":[17,0,0,29],
"dist__vars_8h.html#aa03194c513af6b860e7b33e370b82bdb":[17,0,0,29,3],
"dist__vars_8h.html#ab65d8ff14c6937612212526a60f59b3c":[17,0,0,29,5],
"dist__vars_8h.html#ac1605fe3448ad0a0b809c4fb8f6a854a":[17,0,0,29,4],
"dist__vars_8h_source.html":[17,0,0,29],
"distance_measures.html":[4,1],
"distance_measures.html#sec_compare_base_pair_probs":[4,1,2],
"distance_measures.html#sec_string_alignment":[4,1,1],
"distance_measures.html#sec_tree_edit_distance":[4,1,0],
"dp__matrices_8h.html":[17,0,0,30],
"dp__matrices_8h_source.html":[17,0,0,30],
"duplex_8h.html":[17,0,0,31],
"duplex_8h_source.html":[17,0,0,31],
"edit__cost_8h.html":[17,0,0,32],
"edit__cost_8h_source.html":[17,0,0,32],
"energy__const_8h.html":[17,0,0,33],
"energy__const_8h_source.html":[17,0,0,33],
"energy__par_8h.html":[17,0,0,34],
"energy__par_8h_source.html":[17,0,0,34],
"energy_evaluation.html":[4,2],
"energy_evaluation.html#sec_energy_parameters":[4,2,1],
"energy_evaluation.html#sec_energy_parameters_api":[4,2,1,0],
"energy_evaluation.html#sec_loop_decomposition":[4,2,0],
"energy_evaluation.html#sec_loop_decomposition_api":[4,2,0,0],
"energy_evaluation.html#sec_model_details":[4,2,2],
"equilibrium__probs_8h.html":[17,0,0,35],
"equilibrium__probs_8h_source.html":[17,0,0,35],
"eval_8h.html":[17,0,0,36],
"eval_8h_source.html":[17,0,0,36],
"examples.html":[9],
"examples_c.html":[9,0],
"examples_c.html#ex_c_callbacks":[9,0,2],
"examples_c.html#ex_c_deprecated":[9,0,5],
"examples_c.html#ex_c_fc":[9,0,1],
"examples_c.html#ex_c_other":[9,0,4],
"examples_c.html#ex_c_sc":[9,0,3],
"examples_c.html#ex_c_simple":[9,0,0],
"examples_perl5.html":[9,1],
"examples_python.html":[9,2],
"exterior__loops_8h.html":[17,0,0,37],
"exterior__loops_8h_source.html":[17,0,0,37],
"external_8h.html":[17,0,0,4,1],
"external_8h_source.html":[17,0,0,4,1],
"file__formats_8h.html":[17,0,0,38],
"file__formats_8h_source.html":[17,0,0,38],
"file__formats__msa_8h.html":[17,0,0,39],
"file__formats__msa_8h_source.html":[17,0,0,39],
"file__utils_8h.html":[17,0,0,40],
"file__utils_8h_source.html":[17,0,0,40],
"file_formats.html":[5,1],
"file_formats.html#command_file_loop_types":[5,1,1,0,2],
"file_formats.html#const_file_orientation":[5,1,1,0,3],
"file_formats.html#const_file_seq_coords":[5,1,1,0,4],
"file_formats.html#const_file_syntax":[5,1,1,0,5],
"file_formats.html#constraint-formats":[5,1,1],
"file_formats.html#constraint-formats-file":[5,1,1,0],
"file_formats.html#constraint_commands":[5,1,1,0,0],
"file_formats.html#domain_commands":[5,1,1,0,1],
"file_formats.html#domains_syntax":[5,1,1,0,6],
"file_formats.html#msa-formats":[5,1,0],
"file_formats.html#msa-formats-clustal":[5,1,0,0],
"file_formats.html#msa-formats-fasta":[5,1,0,2],
"file_formats.html#msa-formats-maf":[5,1,0,3],
"file_formats.html#msa-formats-stockholm":[5,1,0,1],
"files.html":[17,0],
"findpath_8h.html":[17,0,0,41],
"findpath_8h_source.html":[17,0,0,41],
"fold_8h.html":[17,0,0,42],
"fold_8h_source.html":[17,0,0,42],
"fold__compound_8h.html":[17,0,0,43],
"fold__compound_8h_source.html":[17,0,0,43],
"fold__vars_8h.html":[17,0,0,44],
"fold__vars_8h.html#a0244a629b5ab4f58b77590c3dfd130dc":[17,0,0,44,6],
"fold__vars_8h.html#a0afc287c2464866d94858c39175154af":[17,0,0,44,0],
"fold__vars_8h.html#a5dbaa0cca2c8c82048a0f0e38e164944":[17,0,0,44,2],
"fold__vars_8h.html#a80c3c5fd35e7479704cc91d2d0367743":[17,0,0,44,4],
"fold__vars_8h.html#a92089ae3a51b5d75a14ce9cc29cc8317":[17,0,0,44,8],
"fold__vars_8h.html#ab9b2c3a37a5516614c06d0ab54b97cda":[17,0,0,44,5],
"fold__vars_8h.html#ac98ec419070aee6831b44e5c700f090f":[17,0,0,44,7],
"fold__vars_8h.html#af2763d55a74663a5e60652b8880baa5b":[17,0,0,44,1],
"fold__vars_8h.html#af349001ad3b4d008d0051d935b1b6261":[17,0,0,44,3],
"fold__vars_8h_source.html":[17,0,0,44],
"fold_compound_container.html":[6,1],
"folding_grammar.html":[4,3],
"folding_grammar.html#sec_constraints":[4,3,2],
"folding_grammar.html#sec_constraints_hard_api":[4,3,2,0],
"folding_grammar.html#sec_constraints_soft_api":[4,3,2,1],
"folding_grammar.html#sec_domains":[4,3,1],
"folding_grammar.html#sec_domains_api":[4,3,1,2],
"folding_grammar.html#sec_domains_structured":[4,3,1,0],
"folding_grammar.html#sec_domains_up":[4,3,1,1],
"folding_grammar.html#sec_recursions":[4,3,0],
"functions.html":[16,2,0],
"functions.html":[16,2,0,0],
"functions_b.html":[16,2,0,1],
"functions_c.html":[16,2,0,2],
"functions_d.html":[16,2,0,3],
"functions_e.html":[16,2,0,4],
"functions_f.html":[16,2,0,5],
"functions_g.html":[16,2,0,6],
"functions_h.html":[16,2,0,7],
"functions_i.html":[16,2,0,8],
"functions_j.html":[16,2,0,9],
"functions_k.html":[16,2,0,10],
"functions_l.html":[16,2,0,11],
"functions_m.html":[16,2,0,12],
"functions_n.html":[16,2,0,13],
"functions_o.html":[16,2,0,14],
"functions_p.html":[16,2,0,15],
"functions_q.html":[16,2,0,16],
"functions_r.html":[16,2,0,17],
"functions_s.html":[16,2,0,18],
"functions_t.html":[16,2,0,19],
"functions_u.html":[16,2,0,20],
"functions_vars.html":[16,2,1],
"functions_vars.html":[16,2,1,0]
};
